Computes an approximation of \(\int_start^stop S(t) dt\), where \(S(t)\) is a survival function, for a selection of start and stop time points.
Usage
int_surv(times, surv, start = 0, stop = max(times), extend = FALSE)Computes an approximation of \(\int_start^stop S(t) dt\), where \(S(t)\) is a survival function, for a selection of start and stop time points.
int_surv(times, surv, start = 0, stop = max(times), extend = FALSE)