View source: R/learner_surv_rf.R
| learner_surv_rf | R Documentation |
Constructs a learner class object for random survival forests
learner_surv_rf(
formula,
info = "survival forest (ranger)",
num.threads = 1L,
learner.args = NULL,
...
)
formula |
(formula) Formula specifying response and design matrix. |
info |
(character) Optional information to describe the instantiated learner object. |
num.threads |
Number of threads. Use 0 for all available cores. Default is 2 if not set by options/environment variables (see below). |
learner.args |
(list) Additional arguments to learner$new(). |
... |
Further arguments passed to or from other methods (currently ignored). |
learner object.
Klaus Kähler Holst
data(sTRACE, package="mets")
mod <- learner_surv_rf(Surv(time, status>0) ~ sex + age)
mod$estimate(sTRACE)
mod$predict(head(sTRACE), times=5) # P(T>t|X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.