powered by
Constructs a learner class object for random survival forests
learner_surv_rf( formula, info = "survival forest (ranger)", num.threads = 1L, learner.args = NULL, ... )
learner object.
(formula) Formula specifying response and design matrix.
(character) Optional information to describe the instantiated learner object.
Number of threads. Use 0 for all available cores. Default is 2 if not set by options/environment variables (see below).
(list) Additional arguments to learner$new().
Further arguments passed to or from other methods (currently ignored).
Klaus Kähler Holst
data(sTRACE, package="mets") mod <- learner_surv_rf(Surv(time, status>0) ~ sex + age) mod$estimate(sTRACE) mod$predict(head(sTRACE), times=5) # P(T>t|X)
Run the code above in your browser using DataLab