Constructs a learner class object for fitting support vector
machines with e1071::svm. As shown in the examples, the constructed learner
returns predicted class probabilities of class 2 in case of binary
classification. A n times p matrix, with n being the number of
observations and p the number of classes, is returned for multi-class
classification.
Usage
learner_svm(
formula,
info = "e1071::svm",
cost = 1,
epsilon = 0.1,
kernel = "radial",
learner.args = NULL,
...
)Arguments
- formula
(formula) Formula specifying response and design matrix.
- info
(character) Optional information to describe the instantiated learner object.
- cost
cost of constraints violation (default: 1)—it is the ‘C’-constant of the regularization term in the Lagrange formulation.
- epsilon
epsilon in the insensitive-loss function (default: 0.1)
- kernel
the kernel used in training and predicting. You might consider changing some of the following parameters, depending on the kernel type.
- linear:
\(u'v\)
- polynomial:
\((\gamma u'v + coef0)^{degree}\)
- radial basis:
\(e^(-\gamma |u-v|^2)\)
- sigmoid:
\(tanh(\gamma u'v + coef0)\)
- learner.args
(list) Additional arguments to learner$new().
- ...
Additional arguments to e1071::svm.
Value
learner object.
Examples
n <- 5e2
x1 <- rnorm(n, sd = 2)
x2 <- rnorm(n)
lp <- x2*x1 + cos(x1)
yb <- rbinom(n, 1, lava::expit(lp))
y <- lp + rnorm(n, sd = 0.5**.5)
d <- data.frame(y, yb, x1, x2)
# regression
lr <- learner_svm(y ~ x1 + x2)
lr$estimate(d)
lr$predict(head(d))
#> 1 2 3 4 5 6
#> 2.6735533 1.1992319 1.0885052 -2.2480818 5.3942965 -0.8926302
# binary classification
lr <- learner_svm(as.factor(yb) ~ x1 + x2)
# alternative to transforming response variable to factor
# lr <- learner_svm(yb ~ x1 + x2, type = "C-classification")
lr$estimate(d)
lr$predict(head(d)) # predict class probabilities of class 2
#> 1 2 3 4 5 6
#> 0.1426360 0.1205889 0.1857578 0.8982848 0.1000418 0.5260114
lr$predict(head(d), probability = FALSE) # predict labels
#> 1 2 3 4 5 6
#> 1 1 1 0 1 1
#> Levels: 0 1
# multi-class classification
lr <- learner_svm(Species ~ .)
lr$estimate(iris)
lr$predict(head(iris))
#> setosa versicolor virginica
#> 1 0.9800063 0.01170421 0.008289509
#> 2 0.9722969 0.01881110 0.008891995
#> 3 0.9787042 0.01235736 0.008938397
#> 4 0.9745057 0.01589782 0.009596491
#> 5 0.9791698 0.01205585 0.008774312
#> 6 0.9734446 0.01743760 0.009117831