Constructs a learner class object for fitting support vector
machines with e1071::svm. As shown in the examples, the constructed learner
returns predicted class probabilities of class 2 in case of binary
classification. A n times p matrix, with n being the number of
observations and p the number of classes, is returned for multi-class
classification.
Usage
learner_svm(
formula,
info = "e1071::svm",
cost = 1,
epsilon = 0.1,
kernel = "radial",
learner.args = NULL,
...
)Arguments
- formula
(formula) Formula specifying response and design matrix.
- info
(character) Optional information to describe the instantiated learner object.
- cost
cost of constraints violation (default: 1)—it is the ‘C’-constant of the regularization term in the Lagrange formulation.
- epsilon
epsilon in the insensitive-loss function (default: 0.1)
- kernel
the kernel used in training and predicting. You might consider changing some of the following parameters, depending on the kernel type.
- linear:
\(u'v\)
- polynomial:
\((\gamma u'v + coef0)^{degree}\)
- radial basis:
\(e^(-\gamma |u-v|^2)\)
- sigmoid:
\(tanh(\gamma u'v + coef0)\)
- learner.args
(list) Additional arguments to learner$new().
- ...
Additional arguments to e1071::svm.
Value
learner object.
Examples
n <- 5e2
x1 <- rnorm(n, sd = 2)
x2 <- rnorm(n)
lp <- x2*x1 + cos(x1)
yb <- rbinom(n, 1, lava::expit(lp))
y <- lp + rnorm(n, sd = 0.5**.5)
d <- data.frame(y, yb, x1, x2)
# regression
lr <- learner_svm(y ~ x1 + x2)
lr$estimate(d)
lr$predict(head(d))
#> 1 2 3 4 5 6
#> 2.4336616 0.2706190 2.8369946 0.3111554 -2.5190433 0.1482316
# binary classification
lr <- learner_svm(as.factor(yb) ~ x1 + x2)
# alternative to transforming response variable to factor
# lr <- learner_svm(yb ~ x1 + x2, type = "C-classification")
lr$estimate(d)
lr$predict(head(d)) # predict class probabilities of class 2
#> 1 2 3 4 5 6
#> 0.1499758 0.2855602 0.1434181 0.4394756 0.9239652 0.3302576
lr$predict(head(d), probability = FALSE) # predict labels
#> 1 2 3 4 5 6
#> 1 1 1 1 0 1
#> Levels: 0 1
# multi-class classification
lr <- learner_svm(Species ~ .)
lr$estimate(iris)
lr$predict(head(iris))
#> setosa versicolor virginica
#> 1 0.9799494 0.01115064 0.008899961
#> 2 0.9725617 0.01789033 0.009548006
#> 3 0.9786258 0.01176853 0.009605658
#> 4 0.9745640 0.01512080 0.010315219
#> 5 0.9791193 0.01146491 0.009415778
#> 6 0.9736901 0.01653393 0.009776010