Implements the discrete super learner: the candidate learner
with the lowest risk (computed via the model.score argument of
superlearner) is given weight one and all other learners weight zero.
Implements the discrete super learner: the candidate learner
with the lowest risk (computed via the model.score argument of
superlearner) is given weight one and all other learners weight zero.