Implements the discrete super learner: the candidate learner
with the lowest risk (computed via the model.score argument of
superlearner) is given weight one and all other learners weight zero.
metalearner_discrete(y, pred, model.score, ...)(numeric) Vector of ensemble weights, one element per column of
pred.
(numeric) Response vector.
(matrix) Matrix of cross-validated predictions with one column per candidate learner.
(function) Method for scoring the predictions of each base learner.
Additional arguments (currently ignored).
superlearner learner_sl