| metalearner_nnls | R Documentation |
Estimates the ensemble weights of a superlearner by minimizing the cross-validated MSE via non-negative least squares regression. The estimated weights are non-negative and normalized to sum to one.
metalearner_nnls(y, pred, method = "quadprog", ...)
y |
(numeric) Response vector. |
pred |
(matrix) Matrix of cross-validated predictions with one column per candidate learner. |
method |
(character) Quadratic-programming solver used to compute the
non-negative least squares weights. Either |
... |
Additional arguments (currently ignored). |
targeted:::metalearner_nnls2 is an internal wrapper for using the
"nnls" package instead of "quadprog".
(numeric) Vector of ensemble weights, one element per column of
pred.
superlearner learner_sl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.