| moi_missing | R Documentation |
Estimates the mean of a given parametric imputation model among observations
with a missing outcome and a given treatment. Specifically, it provides
estimates of E[U(X,A,Z;\theta)|A=a, \Delta=0], for an imputation model
U, where X denotes baseline covariates, A denotes the
treatment, Z denotes post randomization covariates, and \Delta
denotes a non-missing indicator. Influence function based standard errors are
also provided.
moi_missing(
data,
id,
delta,
treatment.model,
imputation.model,
imputation.subset = NULL,
imputation.augmentation = FALSE,
missing.model = NULL,
imputation.augmentation.model = NULL,
extended.output = FALSE
)
id |
A vector with subject IDs |
treatment.model |
A |
imputation.model |
A learner object of class 'learner_glm' used to fit
the imputation model. The learner must specify the outcome variable and
model formula. If the learner was constructed with user-supplied
|
missing.model |
|
imputation.augmentation.model |
|
extended.output |
Logical. If |
A list with components:
estimate |
A |
imputation.model |
The fitted imputation model. |
imputation.subset |
The |
levels |
Treatment levels (character). |
IC3 |
(only if |
IC_epsilon |
(only if |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.