Estimates the mean of a given parametric imputation model among observations with a missing outcome and a given treatment. Specifically, it provides estimates of \(E[U(X,A,Z;\theta)|A=a, \Delta=0]\), for an imputation model \(U\), where \(X\) denotes baseline covariates, \(A\) denotes the treatment, \(Z\) denotes post randomization covariates, and \(\Delta\) denotes a non-missing indicator. Influence function based standard errors are also provided.
moi_missing(
data,
id,
delta,
treatment.model,
imputation.model,
imputation.subset = NULL,
imputation.augmentation = FALSE,
missing.model = NULL,
imputation.augmentation.model = NULL,
extended.output = FALSE
)A list with components:
A lava::estimate object with coefficients
\(E[U|A=1,\Delta=0]\) and \(E[U|A=0,\Delta=0]\) and the
associated influence functions.
The fitted imputation model.
The imputation.subset expression.
Treatment levels (character).
(only if extended.output = TRUE and
imputation.augmentation = TRUE) Named list (one entry per
treatment level) giving the per-level augmentation contribution to
the influence function.
(only if extended.output = TRUE) Influence
function for the imputation-model parameters.
A vector with subject IDs
A learner object for the binary treatment,
used to extract the treatment variable and its levels.
A learner object of class 'learner_glm' used to fit
the imputation model. The learner must specify the outcome variable and
model formula. If the learner was constructed with user-supplied
weights, those weights are multiplied by the
imputation.subset indicator (excluded rows receive zero weight).
learner object
specifying the model for the probability of the outcome being
observed/non-missing
learner object
specifying the model for the imputation augmentation
Logical. If TRUE, the returned list also
includes the augmentation component IC3 of the influence
function (only when imputation.augmentation = TRUE) and the
imputation-model influence function IC_epsilon. Default is
FALSE.