For a user defined function \(H(u|X)\), computes the integral \(\int_0^\tau \frac{H(u)|X}{S^c}\) dM^c(u|X), where $S^c$ is the censoring time survival function and $M^c$ is the censoring is the right censoring martingale with the Doob-Meyer decomposition \(M^c = N^c - L^c\), where \(N^c\) is the counting process \(N^c(s) = I\{\tilde T \leq s \Delta = 0\}\) and \(L^c\) is the compensator \(L^c(s) = \int_0^s I \{\tilde T \geq u\} d\Lambda^c(u|X)\).
rcai(
T_model,
C_model,
data,
time,
event,
tau,
H_constructor,
sample = 0,
blocksize = 0,
return_all = FALSE,
...
)vector with integral from 0 to all jump-times
model for event time
model for censoring
data.frame
time variable
event variable
stopping time
function H(u|X)
approximate integral by subsampling jump-times
evaluate cumhaz in chunks of size blocksize
if TRUE then bot counting process N and compensator term L are returned
additional arguments passed to lower level functions
Andreas Nordland