powered by
The functions riskreg and ate returns an object of the type targeted.
riskreg
ate
targeted
An object of class 'targeted' is a list with at least the following components:
An estimate object with the target parameter estimates (see estimate.default)
estimate
estimate.default
Object returned from the applied optimization routine
number of parameters of the model (target and nuisance)
String describing the model
objects of the S3 class 'targeted'
The following S3 generic functions are available for an object of class targeted:
coefExtract target coefficients of the estimated model.
coef
vcovExtract the variance-covariance matrix of the target parameters.
vcov
ICExtract the estimated influence function.
IC
printPrint estimates of the target parameters.
print
summaryExtract information on both target parameters and estimated nuisance model.'
summary
riskreg, ate
## See example(riskreg) for examples
Run the code above in your browser using DataLab