powered by
Methods for targeted and semiparametric inference including augmented inverse probability weighted estimators for missing data and causal inference.
Klaus K. Holst (Maintainer) klaus@holst.it
example(riskreg) example(cate) example(ate) example(calibration)
Run the code above in your browser using DataLab